@@ -61,7 +61,7 @@ def linetotalchecker(FILENAME,TOTALNUMBER):
                 if TOTALNUMBER in x:
                     print(bcolors.OKGREEN +"Counted line is correct" + bcolors.ENDC  )
                     break
-                if TOTALNUMBER not in x:
+                elif TOTALNUMBER not in x:
                     print(bcolors.FAIL +"Counted line is incorrect" + bcolors.ENDC  )
                     break
     except FileNotFoundError:
